module.exports = {
	description: 'uses const instead of var if specified (#653)',
	options: {
		preferConst: true,
		output: { name: 'myBundle' }
	}
};
